@@ -27,8 +27,8 @@ if ( $ENV->cli->{opt}->{debug} ) {
 
     if ( $res->server ) {
         say 'SERVER: ' . $res->server->host;
-        say 'SERVER NOT FOUND RE: ' . ( $res->server->notfound_re ? join q[, ], $res->server->notfound_re->@* : 'not defined' );
-        say 'SERVER EXCEED RE: ' .    ( $res->server->exceed_re   ? join q[, ], $res->server->exceed_re->@*   : 'not defined' );
+        say 'SERVER NOT FOUND RE: ' . ( $res->server->notfound_re // 'not defined' );
+        say 'SERVER EXCEED RE: ' .    ( $res->server->exceed_re   // 'not defined' );
         say 'SERVER QUERY: ' . dump $res->server->query;
     }
 
